function gs2dsys = mainGPE2dsys
addpath('Hermite');
addpath(['..',filesep,'common']);
% Dirac constant
hbar = 1.054571628e-34;
%%% USER DEFINED PARAMETERS
% Number of components
l = 3;
% Number of Hermite functions in x and y direction
NH = [64; 64; 64]; 
h = hbar;
% Atomic masses of the species
m = [1.44e-25; 1.44e-25; 1.44e-25];
% Number of particles
N = [1e7; 1e7; 1e7];
% coupling constants (only the upper triangular part is needed)
g = [1e-6, 1e-5, 1e-5; 1e-5, 1e-6, 1e-5; 1e-5, 1e-5, 1e-6];
% frequencies in the potentials
omega = [1.5*pi, pi; pi 2*pi; 1.5*pi pi];
% Scale of Hermite functions
beta = sqrt(min(omega,2));
% x range (used only for the plot). The y range is equal to the x range (but can be modified inside function plots).
% The z range is automatic.
xmin = -3;
xmax = 3;
% How much fine is the surface (used only for the plot)
M = 101;
% Function names of the potentials
potential{1} = @potential1;
potential{2} = @potential2;
potential{3} = @potential3;
%%% END OF USER DEFINED PARAMETERS, but, GOTO potential1,...
c = (prod(m)^(1/l))/h;
for i = 1:l
  for j = 1:l
    theta(i,j) = 2*pi*c*h*g(i,j)*(m(i)+m(j))/(m(i)*m(j));  
  end
end
% overwrite theta
theta(1,2) = 0;
theta(1,2) = 1.3e-6;
theta(1,2) = 2.5e-6;
theta(1,2) = 5e-6;
theta(1,2) = 1e-5;
theta = theta(1,2)*ones(l);
theta(1,1) = 1.3e-5;
theta(3,3) = theta(1,1);
theta(2,2) = 6.3e-8;
tic
[phis,mu,energy] = groundstate2dsys(h,c,N,theta,NH,beta,0,potential,m,omega);
toc
gs2dsys.h = h;
gs2dsys.m = m;
gs2dsys.N = N;
gs2dsys.g = g;
gs2dsys.omega = omega;
gs2dsys.sqrtc = sqrt(c);
for i = 1:l
  gs2dsys.phis{i} = phis{i};
  gs2dsys.potential{i} = potential{i};
end
gs2dsys.mu = mu;
gs2dsys.energy = energy;		  
% Plots functions
plots2dsys(M,xmin,xmax,c,phis,beta)

function z = potential1(x,y,m,omega)
% potential V1
% center displacement
x0 = -1e-5;
y0 = 0;
% rotation
Omega = 0;
z = m*((omega(1)*(cos(Omega)*(x-x0)+sin(Omega)*(y-y0))).^2+...
(omega(2)*(sin(Omega)*(x-x0)-cos(Omega)*(y-y0))).^2)/2;

function z = potential2(x,y,m,omega)
% potential V2
% center displacement
x0 = 0;
y0 = 0;
% rotation
Omega = pi/4;
z = m*((omega(1)*(cos(Omega)*(x-x0)+sin(Omega)*(y-y0))).^2+...
(omega(2)*(sin(Omega)*(x-x0)-cos(Omega)*(y-y0))).^2)/2;

function z = potential3(x,y,m,omega)
% potential V3  
% center displacement
x0 = 1e-5;
y0 = 0;
% rotation
Omega = 0;
z = m*((omega(1)*(cos(Omega)*(x-x0)+sin(Omega)*(y-y0))).^2+...
(omega(2)*(sin(Omega)*(x-x0)-cos(Omega)*(y-y0))).^2)/2;


