% Splitting methods 
function [s,a,b] = methodcoefficients(method)
% Order 2 (Strang)
if method == 2 
    s = 2; 
    a(1) = 0;
    a(2) = 1;
    b(1) = 1/2;
    b(2) = b(1);
end 
% Order 2 (Hairer/Lubich/Wanner, p. 138, (3.3))
if method == 21 
    s = 3; 
    alpha = 1/4;    
    a(1) = 0;
    a(2) = 1/2;
    a(3) = a(2);
    b(1) = alpha;
    b(2) = 1 - 2*alpha;
    b(3) = b(1);
end 
% Order 2 (Maclachlan, see Hairer/Lubich/Wanner, p. 138, (3.3))
if method == 211 
    s = 3; 
    alpha = 0.1932;    
    a(1) = 0;
    a(2) = 1/2;
    a(3) = a(2);
    b(1) = alpha;
    b(2) = 1 - 2*alpha;
    b(3) = b(1);
end 
% Order 4 (Yoshida, see Hairer/Lubich/Wanner, p. 40, (4.4))
if method == 4
    s = 4;
    pp = 3;
    gamma(1) = 1/(2-2^(1/pp));
    gamma(2) = - 2^(1/pp)*gamma(1);
    a(1) = 0;
    a(2) = gamma(1);
    a(3) = gamma(2);
    a(4) = a(2);
    b(1) = gamma(1)/2;
    b(2) = sum(gamma)/2;
    b(3:4) = reshape(flipud(b(1:2)'),1,2);
end 
% Order 4 (Suzuki, see Hairer/Lubich/Wanner, p. 41, (4.5))
if method == 40
    s = 6;
    pp = 3;
    gamma(1) = 1/(4-4^(1/pp));
    gamma(2) = - 4^(1/pp)*gamma(1);
    a(1) = 0;
    a(2) = gamma(1);
    a(3) = a(2);
    a(4) = gamma(2);
    a(5:6) = reshape(flipud(a(2:3)'),1,2);
    b(1) = gamma(1)/2;
    b(2) = gamma(1);
    b(3) = sum(gamma)/2;
    b(4:6) = reshape(flipud(b(1:3)'),1,3);
end 
% Order 4 (Maclachlan, see Hairer/Lubich/Wanner, p. 140, (3.6))
if method == 41
    s = 6; 
    alpha(1) = (146 + 5*sqrt(19))/540;
    alpha(2) = (-2 + 10*sqrt(19))/135;
    alpha(3) = 1/5;
    alpha(4) = - (23 + 20*sqrt(19))/270;
    alpha(5) = (14 - sqrt(19))/108;
    beta = reshape(flipud(alpha'),1,5);
    a(1) = 0;
    b(1) = beta(1); 
    for i = 2:s-1
        a(i) = alpha(i-1) + beta(i-1); 
        b(i) = alpha(i-1) + beta(i); 
    end 
    a(s) = alpha(s-1) + beta(s-1); 
    b(s) = alpha(s-1);
end 
% Order 4 (Blanes/Moan, Table 2, PRK)
if method == 411 
    s = 7;
    a(1) = 0.0792036964311957;
    a(2) = 0.3531729060497740;
    a(3) = -0.0420650803577195; 
    a(4) = 1 - 2*(sum(a(1:3))); 
    b(1) = 0.209515106613362;
    b(2) = -0.143851773179818;
    b(3) = 1/2 - sum(b(1:2));
    a(5:7) = reshape(flipud(a(1:3)'),1,3);
    b(4:6) = reshape(flipud(b(1:3)'),1,3);
    b(7) = 0;    
    aa = a;
    a = b;
    b = aa;
    a = [0,a(1:end-1)];
end 
% Order 4 (Blanes/Moan, Table 3, SRKNb6)
if method == 412
    s = 6;
    a(1) = 0.245298957184271;
    a(2) = 0.604872665711080;
    a(3) = 1/2 - sum(a(1:2));
    b(1) = 0.0829844064174052;
    b(2) = 0.396309801498368;
    b(3) = - 0.0390563049223486;
    b(4) = 1 - 2*sum(b(1:3));
    for i = 1:s
        b(s+2-i) = b(i);
        a(s+1-i) = a(i);
    end 
    s = s+1;
    a = [0,a(1:end)];
end 
% Order 6 (Yoshida, see Hairer/Lubich/Wanner, p. 144, (3.11), s = 8)
if method == 6 
    s = 8;
    a(1) = 0;
    a(2) = 0.78451361047755726381949763;
    a(3) = 0.23557321335935813368479318;
    a(4) = -1.17767998417887100694641568;
    a(5) = 1 - 2*sum(a(2:4));
    a(6:8) = reshape(flipud(a(2:4)'),1,3);
    b(1) = 1/2*a(2);
    b(2) = 1/2*sum(a(2:3));
    b(3) = 1/2*sum(a(3:4));
    b(4) = 1/2*(1 - 2*sum(a(2:3))-a(4));
    b(5:8) = reshape(flipud(b(1:4)'),1,4);
end  
% Order 6 (Yoshida, see Hairer/Lubich/Wanner, p. 40, (4.4), s = 10)
if method == 60
    s = 10;
    pp = 3;
    gamma(1) = 1/(2-2^(1/pp));
    gamma(2) = - 2^(1/pp)*gamma(1);
    aa(2) = gamma(1);
    aa(3) = gamma(2);
    bb(1) = gamma(1)/2;
    bb(2) = sum(gamma)/2;
    pp = 5;
    gamma(1) = 1/(2-2^(1/pp));
    gamma(2) = - 2^(1/pp)*gamma(1);
    a(1) = 0;
    a(2:3) = gamma(1)*aa(2:3);
    a(4) = a(2);
    b(1:2) = gamma(1)*bb(1:2);
    b(3) = b(2);
    b(4) = sum(gamma)*bb(1);
    a(5:6) = gamma(2)*aa(2:3);
    b(5) = gamma(2)*bb(2);
    a(7:10) = reshape(flipud(a(2:5)'),1,4);
    b(6:10) = reshape(flipud(b(1:5)'),1,5);
end  
% Order 6 (Kahan/Li, see Hairer/Lubich/Wanner, p. 144, (3.12))
if method == 61 
    s = 10;
    a(1) = 0;
    a(2) = 0.39216144400731413927925056;
    a(3) = 0.33259913678935943859974864;
    a(4) = -0.70624617255763935980996482;
    a(5) = 0.08221359629355080023149045;
    a(6) = 1 - 2*sum(a(2:5));
    a(7:10) = reshape(flipud(a(2:5)'),1,4);
    b(1) = 1/2*a(2);
    b(2) = 1/2*sum(a(2:3));
    b(3) = 1/2*sum(a(3:4));
    b(4) = 1/2*sum(a(4:5));
    b(5) = 1/2*(1 - 2*sum(a(2:4))-a(5));
    b(6:10) = reshape(flipud(b(1:5)'),1,5);
end  
% Order 6 (Suzuki, see Hairer/Lubich/Wanner, p. 41, (4.5))
if method == 600
    s = 26;
    pp = 3;
    gamma(1) = 1/(4-4^(1/pp));
    gamma(2) = - 4^(1/pp)*gamma(1);
    aa(1) = 0;
    aa(2) = gamma(1);
    aa(3) = aa(2);
    aa(4) = gamma(2);
    aa(5:6) = reshape(flipud(aa(2:3)'),1,2);
    bb(1) = gamma(1)/2;
    bb(2) = gamma(1);
    bb(3) = sum(gamma)/2;
    bb(4:6) = reshape(flipud(bb(1:3)'),1,3);
    pp = 5;
    gamma(1) = 1/(4-4^(1/pp));
    gamma(2) = - 4^(1/pp)*gamma(1);
    a(1:6) = gamma(1)*aa(1:6);
    a(7:12) = gamma(1)*aa(1:6);
    a(13:18) = gamma(2)*aa(1:6);
    a(19:24) = gamma(1)*aa(1:6);
    a(25:30) = gamma(1)*aa(1:6);
    b(1:6) = gamma(1)*bb(1:6);
    b(7:12) = gamma(1)*bb(1:6);
    b(13:18) = gamma(2)*bb(1:6);
    b(19:24) = gamma(1)*bb(1:6);
    b(25:30) = gamma(1)*bb(1:6);
    a = [a(1:6),a(8:12),a(14:18),a(20:24),a(26:30)];
    b = [b(1:5),b(6)+b(7),b(8:11),b(12)+b(13),b(14:17),b(18)+b(19),b(20:23),b(24)+b(25),b(26:30)];
end  
% Order 6 (Blanes/Moan, Table 2, PRK)
if method == 611 
    s = 11;
    a(1) = 0.0502627644003922;
    a(2) = 0.413514300428344;
    a(3) = 0.0450798897943977;
    a(4) = -0.188054853819569;
    a(5) = 0.541960678450780;
    a(6) = 1 - 2*sum(a(1:5));
    a(7:11) = reshape(flipud(a(1:5)'),1,5);
    b(1) = 0.148816447901042;
    b(2) = -0.132385865767784;
    b(3) = 0.067307604692185;
    b(4) = 0.432666402578175;
    b(5) = 1/2 - sum(b(1:4));
    b(6:10) = reshape(flipud(b(1:5)'),1,5);
    b(11) = 0;
    aa = a;
    a = b;
    b = aa;
    a = [0,a(1:end-1)];
end
% Order 6 (Blanes/Moan, Table 3, SRKNb11) - Wrong order!!!  
if method == 612
    s = 11;
    a(1) = 0.123229775946271;
    a(2) = 0.290553797799558;
    a(3) = - 0.127049212625417;
    a(4) = - 0.246331761062075;
    a(5) = 0.357208872795928;
    a(6) = 1 - 2*sum(a(1:5));
    b(1) = 0.0414649985182624;
    b(2) = 0.198128671918067;
    b(3) = - 0.0400061921041533;
    b(4) = 0.0752539843015807;
    b(5) = - 0.0115113874206879; 
    b(6) = 1/2 - sum(b(1:5));
    for i = 1:s
        b(s+2-i) = b(i);
        a(s+1-i) = a(i);
    end 
    s = s+1;
    a = [0,a(1:end)];
end 
% Order 6 (Blanes/Moan, Table 3, SRKNa14)  
if method == 613
    s = 14;
    a(1) = 0.0378593198406116;
    a(2) = 0.102635633102435; 
    a(3) = -0.0258678882665587;
    a(4) = 0.314241403071447;
    a(5) = -0.130144459517415; 
    a(6) = 0.106417700369543;
    a(7) = -0.00879424312851058; 
    a(8) = 1 - 2*sum(a(1:7));    
    b(1) = 0.09171915262446165;
    b(2) = 0.183983170005006;
    b(3) = -0.05653436583288827;
    b(4) = 0.004914688774712854;
    b(5) = 0.143761127168358;
    b(6) = 0.328567693746804;
    b(7) = 1/2 - sum(b(1:6));
    for i = 1:s/2
        a(s+2-i) = a(i);
        b(s+1-i) = b(i);
    end 
    s = s+1;
    b = [0,b(1:end)];
    aa = a;
    a = b;
    b = aa; 
end 